@@ -11,7 +11,7 @@ import Musicians
 from Instrument import Instrument
 
 try:
-	from mingus.extra import fluidsynth
+	from mingus.midi import fluidsynth
 except:
 	print "Couldn't load the music library mingus."
 	print "A download is available at http://mingus.googlecode.com/"
@@ -65,6 +65,10 @@ if __name__ == '__main__':
 		help="List [blocks, ensembles, progressions, instruments]. Don't play.")
 	parser.add_option("-k", "--key", dest="key",
 		help="Set the key to start in.")
+	parser.add_option("-n", "--no-fluidsynth", dest="no_fluidsynth",
+		action="store_true", default=False, help="Don't connect to a fluidsynth server, just write the midi file."),
+	parser.add_option("-o", "--output-file", dest="midifile", 
+		help="The file to write the midi to.", default="improviser.mid"),
 	parser.add_option("-p", "--progression", dest="progression",
 		help="Set the progression.")
 	parser.add_option("-r", "--resolution", dest="resolution",
@@ -73,6 +77,8 @@ if __name__ == '__main__':
 	parser.add_option("-q", "--quiet", action="store_false",
 		dest="verbose", default=True, 
 		help="Don't output to stdout")
+	parser.add_option("--reverb", action="store_true",
+		dest="reverb", default=False, help="Enable reverb.")
 	parser.add_option("-s", "--swing", action="store_true",
 		dest="swing", default=False, help="Set swing")
 	parser.add_option("-w", "--wildness", type="float", dest="wild",
@@ -174,16 +180,26 @@ if __name__ == '__main__':
 	if options.wild != None:
 		block.wildness = options.wild
 
-	if not fluidsynth.init_fluidsynth():
-		print "No running fluidsynth server found at port 9800."
-		sys.exit(1)
-	fluidsynth.midi.stop_everything()
+	if not options.no_fluidsynth:
+		if not fluidsynth.init_fluidsynth():
+			print "No running fluidsynth server found at port 9800."
+			sys.exit(1)
+		fluidsynth.stop_everything()
+		if options.reverb:
+			fluidsynth.enable_reverb()
+		else:
+			fluidsynth.disable_reverb()
 
 	if block.instruments == []:
 		print "No instruments or ensemble selected."
 
+	for x in block.instruments:
+		x.no_fluidsynth = options.no_fluidsynth
+
 	seq = Sequencer(block)
 	seq.verbose = options.verbose
+	seq.no_fluidsynth = options.no_fluidsynth
+	seq.output_file = options.midifile
 	if visual != None:
 		seq.paint_function = visual.paint_screen
 		seq.refresh_function = visual.refresh_screen
