@@ -5,6 +5,7 @@ from time import sleep, time
 from random import random
 from mingus.core import chords
 from mingus.midi import MidiFileOut
+from os import sys
 
 class Sequencer:
 
@@ -48,7 +49,13 @@ class Sequencer:
 		
 		if self.chord != self.state["chord"]:
 			if self.verbose:
-				print chords.determine(self.chord)[0]
+				if not self.no_fluidsynth:
+					if len(self.chord) != 0:
+						print chords.determine(self.chord)[0]
+					else:
+						print "Unknown chord:", self.chord
+				else:
+					sys.stdout.write("|");
 			self.state["scale"] = \
 				diatonic.get_notes(self.key)
 			for n in self.chord:
@@ -73,7 +80,10 @@ class Sequencer:
 		"""Gets called each iteration -- when self.progression """
 		"""changes or gets repeated."""
 		if self.verbose:
-			print "-" * 20
+			if self.no_fluidsynth:
+				print "|"
+			else:
+				print "-" * 20
 		self.iterations += 1
 		self.play_iterations -= 1
 		self.block_iteration()
@@ -87,7 +97,8 @@ class Sequencer:
 	def play_instruments(self):
 		"""Plays all the instruments in self.instruments if """
 		"""they are currently enabled."""
-		
+		if self.no_fluidsynth:
+			sys.stdout.write(".")
 		it = self.iterations -1 
 		for i in self.instruments:
 			if it >= i.start and (it < i.end or i.end == -1):
@@ -132,6 +143,7 @@ class Sequencer:
 	def output_midi(self):
 		c = Composition()
 		chan = []
+		print 
 		print "Writing MIDI file %s..." % self.output_file
 		for s in self.instruments:
 			if hasattr(s, 'bar'):
